%define major		1
%define libname		%mklibname netcdf_c++4_ %{major}
%define develname	%mklibname netcdf_c++4 -d

Summary:	Libraries to use the Unidata network Common Data Form (netCDF)
Name:		netcdf-cxx4
Version:	4.3.0
Release:	%mkrel 7
Group:		Development/C++
License:	NetCDF
URL:		https://www.unidata.ucar.edu/downloads/netcdf/index.jsp
Source0:	https://github.com/Unidata/netcdf-cxx4/archive/v%{version}/%{name}-%{version}.tar.gz
BuildRequires:	pkgconfig(netcdf)
BuildRequires:	valgrind
BuildRequires:	texinfo
BuildRequires:	tetex-latex
BuildRequires:	groff

%description
NetCDF (network Common Data Form) is an interface for array-oriented data
access and a freely-distributed collection of software libraries for C,
Fortran, C++, and perl that provides an implementation of the interface.
The netCDF library also defines a machine-independent format for representing
scientific data. Together, the interface, library, and format support the
creation, access, and sharing of scientific data. The netCDF software was
developed at the Unidata Program Center in Boulder, Colorado.

NetCDF data is:

   o Self-Describing. A netCDF file includes information about the data it
     contains.

   o Network-transparent. A netCDF file is represented in a form that can be
     accessed by computers with different ways of storing integers, characters,
     and floating-point numbers.

   o Direct-access. A small subset of a large dataset may be accessed
     efficiently, without first reading through all the preceding data.

   o Appendable. Data can be appended to a netCDF dataset along one dimension
     without copying the dataset or redefining its structure. The structure of
     a netCDF dataset can be changed, though this sometimes causes the dataset
     to be copied.

   o Sharable. One writer and multiple readers may simultaneously access the
     same netCDF file.

%package -n	%{libname}
Summary:	C++ libraries for netcdf-4
Group:		System/Libraries

%description -n	%{libname}
This package contains the netCDF-4 C++ libraries.

%package -n	%{develname}
Summary:	Development files for netcdf-4
Group:		Development/C++
Requires:	%{libname} = %{version}-%{release}
Provides:	%{name}-devel = %{version}-%{release}
Conflicts:	%{_lib}netcdf-devel < 4.2.1.1
Conflicts:	%{_lib}netcdf_c++-devel < 4.2-2

%description -n %{develname}
This package contains the netCDF-4 header files, shared devel libs, and
man pages.

%prep
%setup -q

%build
%configure --enable-shared --disable-static
%make_build

%install
%make_install

find %{buildroot} -name '*.la' -delete

%files -n %{libname}
%{_libdir}/libnetcdf_c++4.so.%{major}{,.*}

%files -n %{develname}
%{_bindir}/ncxx4-config
%{_includedir}/*.h
%{_includedir}/netcdf
%{_libdir}/libnetcdf_c++4.so
%{_libdir}/pkgconfig/netcdf-cxx4.pc


%changelog
* Mon Oct 26 2020 akien <akien> 4.3.0-7.mga8
+ Revision: 1639579
- Rebuild against libnetcdf18

* Thu Oct 01 2020 pterjan <pterjan> 4.3.0-6.mga8
+ Revision: 1631528
- Rebuild for new netcdf on arm

* Wed Mar 18 2020 daviddavid <daviddavid> 4.3.0-5.mga8
+ Revision: 1557601
- rebuild for new netcdf 4.7.3

* Thu Feb 13 2020 umeabot <umeabot> 4.3.0-4.mga8
+ Revision: 1515345
- Mageia 8 Mass Rebuild
+ wally <wally>
- replace deprecated %%configure2_5x

* Sun Sep 23 2018 umeabot <umeabot> 4.3.0-3.mga7
+ Revision: 1299704
- Mageia 7 Mass Rebuild

* Wed Aug 01 2018 eatdirt <eatdirt> 4.3.0-2.mga7
+ Revision: 1246650
- Rebuild for new netcdf

* Thu Apr 12 2018 kekepower <kekepower> 4.3.0-1.mga7
+ Revision: 1218081
- Update to version 4.3.0

* Mon Feb 08 2016 umeabot <umeabot> 4.2.1-4.mga6
+ Revision: 943252
- Mageia 6 Mass Rebuild

* Wed Oct 15 2014 umeabot <umeabot> 4.2.1-3.mga5
+ Revision: 745567
- Second Mageia 5 Mass Rebuild

* Tue Sep 16 2014 umeabot <umeabot> 4.2.1-2.mga5
+ Revision: 682847
- Mageia 5 Mass Rebuild

* Thu May 29 2014 fwang <fwang> 4.2.1-1.mga5
+ Revision: 627505
- 4.2.1

* Fri Oct 18 2013 umeabot <umeabot> 4.2-4.mga4
+ Revision: 508310
- Mageia 4 Mass Rebuild
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Fri Oct 12 2012 fwang <fwang> 4.2-2.mga3
+ Revision: 305120
- do not check
- rename devel pacakge
- rename as tarball

* Wed Sep 19 2012 fwang <fwang> 4.2-1.mga3
+ Revision: 296173
- update file list
- update file list
- update tarball dir
- imported package netcdf-c++

